@@ -1,9 +1,10 @@
 from __future__ import absolute_import, division
+from typing import List
 from . import bbox_fitting
-from math import ceil, floor
+from math import ceil
 import numpy as np
 
-def bbox_fitting_center(img, size, padding_value=0):
+def bbox_fitting_center(img: np.ndarray, size, padding_value: int=0) -> np.ndarray:
     '''
     Creates an image of size 'size' ([(int) x, (int) y]) in IMAGE-Coordinates).
     The orignal image will be centered and padded and/or cropped to fit the size.
