@@ -9,8 +9,7 @@ from .. import get_center
 
 def approximate_circle_by_area(contour: np.ndarray) -> Tuple[float, float, float]:
     """
-    approximate a circle with the same area as the contour
-    The center 
+    Returns a circle with the same area and center as the contour.
 
     Args:
         contour (np.ndarray): An opencv contour of a single object
@@ -19,8 +18,8 @@ def approximate_circle_by_area(contour: np.ndarray) -> Tuple[float, float, float
         x: (float) Center x postion
         y: (float) Center y postion
         radius: (float) Radius of the circle
-    """    
+    """
     x, y = get_center(contour)
     area = cv2.contourArea(contour)
-    radius = sqrt(area/pi)
+    radius = sqrt(area / pi)
     return x, y, radius
